I see pretty many warnings of this type:
4(22966) WARNING: <core> [timer.c:448]: WARNING: our timer runs faster
then real-time (1570000 ms / 25120 ticks our time .-> 1569937 ms / 25118
ticks real time)
4(22966) WARNING: <core> [timer.c:448]: WARNING: our timer runs faster
then real-time (1005000 ms / 16080 ticks our time .-> 1002398 ms / 16038
ticks real time)
is it something to ignore?
Cheers,
Daniel
--
Daniel-Constantin Mierla
http://www.asipto.com/index.php/sip-router-bootcamp/
i have this piece of config code:
if (method == "SUBSCRIBE") {
xlog("L_INFO", "Method $rm $ru is SUSBCRIBE\n");
...
exit;
};
xlog("L_INFO", "Method $rm $ru NOT is SUSBCRIBE\n");
and here is what i get to syslog:
Jul 18 09:54:27 localhost /usr/sbin/sip-router[17556]: INFO: Method SUBSCRIBE sip:jh@test.fi NOT is SUSBCRIBE
looks like method test has got broken.
-- juha
Module: sip-router
Branch: master
Commit: 009a8756c1accb2406adecf3e1b20f315f51a24d
URL: http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=009a875…
Author: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Committer: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Date: Sat Jul 18 10:05:16 2009 +0200
core: expr string length fixup fix
- moved the string length fixup before the rve/rval optimisations:
the string length fixup was executed after the rve/rval
optimisations and would try to re-calculate the length of the
string (which was already filled in by the optimizer). However
the rval optimizer did not 0-terminate strings => this second
re-calculation was wrong.
- the rve/rval optimiser 0 terminates strings (although not
strictly needed it's better for debugging and would avoid
problems similar to the above one).
- don't try to fix a string in the left side of an expression,
there can be no strings there (and by chance
METHOD_O==STRING_ST).
Reported-by: Juha Heinanen jh at tutpro com
---
route.c | 30 +++++++++++++-----------------
1 files changed, 13 insertions(+), 17 deletions(-)
diff --git a/route.c b/route.c
index effb608..7c01a3b 100644
--- a/route.c
+++ b/route.c
@@ -435,6 +435,7 @@ static int exp_optimize_right(struct expr* exp)
if (exp->r.str.s){
exp->r.str.len=rval->v.s.len;
memcpy(exp->r.str.s, rval->v.s.s, rval->v.s.len);
+ exp->r.str.s[exp->r.str.len]=0;
exp->r_type=STRING_ST;
rval_destroy(rval);
pkg_free(rve);
@@ -503,6 +504,7 @@ int fix_expr(struct expr* exp)
{
regex_t* re;
int ret;
+ int len;
ret=E_BUG;
if (exp==0){
@@ -525,8 +527,17 @@ int fix_expr(struct expr* exp)
exp->op);
}
}else if (exp->type==ELEM_T){
- /* first fix & optimize rve/rvals (they might be optimized
- to non-rvals, e.g. string, avp a.s.o) */
+ /* first calculate lengths of strings (only right side, since
+ left side can never be a string) */
+ if (exp->r_type==STRING_ST) {
+ if (exp->r.string) len = strlen(exp->r.string);
+ else len = 0;
+ exp->r.str.s = exp->r.string;
+ exp->r.str.len = len;
+ }
+ /* then fix & optimize rve/rvals (they might be optimized
+ to non-rvals, e.g. string, avp a.s.o and needs to be done
+ before MATCH_OP and other fixups) */
if (exp->l_type==RVEXP_O){
if ((ret=fix_rval_expr(&exp->l.param))<0){
ERR("Unable to fix left rval expression\n");
@@ -544,21 +555,6 @@ int fix_expr(struct expr* exp)
exp_optimize_right(exp);
}
- /* Calculate lengths of strings */
- if (exp->l_type==STRING_ST) {
- int len;
- if (exp->l.string) len = strlen(exp->l.string);
- else len = 0;
- exp->l.str.s = exp->l.string;
- exp->l.str.len = len;
- }
- if (exp->r_type==STRING_ST) {
- int len;
- if (exp->r.string) len = strlen(exp->r.string);
- else len = 0;
- exp->r.str.s = exp->r.string;
- exp->r.str.len = len;
- }
if (exp->op==MATCH_OP){
/* right side either has to be string, in which case
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task is now closed:
FS#5 - Compilation on OpenSUSE only is LDAP and H350 modules are removed
User who did this - Andrei Pelinescu-Onciul (andrei)
Reason for closing: Fixed
More information can be found at the following URL:
https://sip-router.org/tracker/index.php?do=details&task_id=5
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
Ser & RTPproxy does not change the SDP vodeo port
-------------------------------------------------
Key: SER-436
URL: http://tracker.iptel.org/browse/SER-436
Project: SER
Issue Type: Bug
Components: NAT Traversal
Environment: Fedora 9
hi,
I'm using ser 0.9.7 and RTPproxy 1.1 on diffrent servers.
the ser.cfg is the nat-rtpproxy.cfg from the iptel site.
I have 2 grandstream GXV-300 devices, each behind diffrent NAT,
this setup is working fine for voice and RTP is relayed through the rtpproxy properly.
The problem is that the video is not working,
when ser gets the invite from device A and send it to device B, it change the audio port only but leave the video port the same as the port he got from device A.
I'm not sure if it is an issue with the RTPproxy or the nat-helper module.
any idea how to debug / resolve? do you aware of other versions of ser/rtpproxy that this setup should work with video?
Thanks!
Amos
--
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://tracker.iptel.org/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task is now closed:
FS#4 - Fix "command out of sync" issue in db_mysql
User who did this - Juha Heinanen (jh)
Reason for closing: Fixed
Additional comments about closing: Fixed by Jan a few weeks ago.
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=4
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task is now closed:
FS#9 - modules_s/domain should export is_local API function
User who did this - Juha Heinanen (jh)
Reason for closing: Fixed
Additional comments about closing: Jan included is_domain_local API function to modules_s/domain.
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=9
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
Hi,
when I try to use a regexp matching for the RURI like this (code is git
master):
if (uri =~ "sip:\+[0-9]+@.*") {
and then send a request with an RURI like this:
sip:+123456789@127.0.0.1
I get the following error message:
2(85781) : <core> [route.c:1190]: BUG: comp_str: Bad operator type 1,
for ~=
and the if statement is obviously not executed?!
Ideas, comments and even more bug fixes are welcome :-)
Regards
Nils